@@ -30,6 +30,12 @@
 
 #include <stddef.h>
 
+#ifdef _WIN32
+#define GLITZ_GL_API_ATTRIBUTE __stdcall
+#else
+#define GLITZ_GL_API_ATTRIBUTE
+#endif
+
 typedef unsigned int glitz_gl_enum_t;
 typedef unsigned char glitz_gl_boolean_t;
 typedef void glitz_gl_void_t;
@@ -106,8 +112,9 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_MAX_TEXTURE_SIZE  0x0D33
 #define GLITZ_GL_MAX_VIEWPORT_DIMS 0x0D3A
 
-#define GLITZ_GL_TEXTURE_WIDTH  0x1000
-#define GLITZ_GL_TEXTURE_HEIGHT 0x1001
+#define GLITZ_GL_TEXTURE_WIDTH        0x1000
+#define GLITZ_GL_TEXTURE_HEIGHT       0x1001
+#define GLITZ_GL_TEXTURE_BORDER_COLOR 0x1004
 
 #define GLITZ_GL_TEXTURE_ENV            0x2300
 #define GLITZ_GL_TEXTURE_ENV_MODE       0x2200
@@ -129,6 +136,7 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_MODULATE               0x2100
 #define GLITZ_GL_NEAREST                0x2600
 #define GLITZ_GL_LINEAR                 0x2601
+#define GLITZ_GL_CLAMP                  0x2900
 #define GLITZ_GL_REPEAT                 0x2901
 #define GLITZ_GL_CLAMP_TO_EDGE          0x812F
 #define GLITZ_GL_CLAMP_TO_BORDER        0x812D
@@ -182,6 +190,9 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_TRANSFORM_BIT      0x00001000
 #define GLITZ_GL_COLOR_BUFFER_BIT   0x00004000
 
+#define GLITZ_GL_STENCIL_INDEX   0x1901
+#define GLITZ_GL_DEPTH_COMPONENT 0x1902
+
 #define GLITZ_GL_ALPHA     0x1906
 #define GLITZ_GL_RGB       0x1907
 #define GLITZ_GL_LUMINANCE 0x1909
@@ -191,24 +202,25 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_BGR       0x80E0
 #define GLITZ_GL_BGRA      0x80E1
 
-#define GLITZ_GL_ALPHA4   0x803B
-#define GLITZ_GL_ALPHA8   0x803C
-#define GLITZ_GL_ALPHA12  0x803D
-#define GLITZ_GL_ALPHA16  0x803E
-#define GLITZ_GL_R3_G3_B2 0x2A10
-#define GLITZ_GL_RGB4     0x804F
-#define GLITZ_GL_RGB5     0x8050
-#define GLITZ_GL_RGB8     0x8051
-#define GLITZ_GL_RGB10    0x8052
-#define GLITZ_GL_RGB12    0x8053
-#define GLITZ_GL_RGB16    0x8054
-#define GLITZ_GL_RGBA2    0x8055
-#define GLITZ_GL_RGBA4    0x8056
-#define GLITZ_GL_RGB5_A1  0x8057
-#define GLITZ_GL_RGBA8    0x8058
-#define GLITZ_GL_RGB10_A2 0x8059
-#define GLITZ_GL_RGBA12   0x805A
-#define GLITZ_GL_RGBA16   0x805B
+#define GLITZ_GL_ALPHA4     0x803B
+#define GLITZ_GL_ALPHA8     0x803C
+#define GLITZ_GL_ALPHA12    0x803D
+#define GLITZ_GL_ALPHA16    0x803E
+#define GLITZ_GL_LUMINANCE8 0x8040
+#define GLITZ_GL_R3_G3_B2   0x2A10
+#define GLITZ_GL_RGB4       0x804F
+#define GLITZ_GL_RGB5       0x8050
+#define GLITZ_GL_RGB8       0x8051
+#define GLITZ_GL_RGB10      0x8052
+#define GLITZ_GL_RGB12      0x8053
+#define GLITZ_GL_RGB16      0x8054
+#define GLITZ_GL_RGBA2      0x8055
+#define GLITZ_GL_RGBA4      0x8056
+#define GLITZ_GL_RGB5_A1    0x8057
+#define GLITZ_GL_RGBA8      0x8058
+#define GLITZ_GL_RGB10_A2   0x8059
+#define GLITZ_GL_RGBA12     0x805A
+#define GLITZ_GL_RGBA16     0x805B
 
 #define GLITZ_GL_FRONT_AND_BACK 0x0408
 #define GLITZ_GL_FLAT           0x1D00
@@ -303,8 +315,14 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_WRITE_ONLY 0x88B9
 #define GLITZ_GL_READ_WRITE 0x88BA
 
-#define GLITZ_GL_FRAMEBUFFER       0x8D40
-#define GLITZ_GL_COLOR_ATTACHMENT0 0x8CE0
+#define GLITZ_GL_FRAMEBUFFER  0x8D40
+#define GLITZ_GL_RENDERBUFFER 0x8D41
+
+#define GLITZ_GL_COLOR_ATTACHMENT0  0x8CE0
+#define GLITZ_GL_COLOR_ATTACHMENT1  0x8CE1
+#define GLITZ_GL_DEPTH_ATTACHMENT   0x8D00
+#define GLITZ_GL_STENCIL_ATTACHMENT 0x8D20
+
 #define GLITZ_GL_FRAMEBUFFER_COMPLETE                        0x8CD5
 #define GLITZ_GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT           0x8CD6
 #define GLITZ_GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT   0x8CD7
@@ -316,212 +334,235 @@ typedef ptrdiff_t glitz_gl_sizeiptr_t;
 #define GLITZ_GL_FRAMEBUFFER_UNSUPPORTED                     0x8CDD
 #define GLITZ_GL_FRAMEBUFFER_STATUS_ERROR                    0x8CDE
 
-typedef glitz_gl_void_t (* glitz_gl_enable_t)
+#define GLITZ_GL_RENDERBUFFER_RED_SIZE     0x8D50
+#define GLITZ_GL_RENDERBUFFER_GREEN_SIZE   0x8D51
+#define GLITZ_GL_RENDERBUFFER_BLUE_SIZE    0x8D52
+#define GLITZ_GL_RENDERBUFFER_ALPHA_SIZE   0x8D53
+#define GLITZ_GL_RENDERBUFFER_DEPTH_SIZE   0x8D54
+#define GLITZ_GL_RENDERBUFFER_STENCIL_SIZE 0x8D55
+
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_enable_t)
      (glitz_gl_enum_t cap);
-typedef glitz_gl_void_t (* glitz_gl_disable_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_disable_t)
      (glitz_gl_enum_t cap);
-typedef glitz_gl_enum_t (* glitz_gl_get_error_t)
+typedef glitz_gl_enum_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_error_t)
      (glitz_gl_void_t);
-typedef glitz_gl_ubyte_t *(* glitz_gl_get_string_t)
+typedef glitz_gl_ubyte_t *(GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_string_t)
      (glitz_gl_enum_t);
-typedef glitz_gl_void_t (* glitz_gl_enable_client_state_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_enable_client_state_t)
      (glitz_gl_enum_t cap);
-typedef glitz_gl_void_t (* glitz_gl_disable_client_state_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_disable_client_state_t)
      (glitz_gl_enum_t cap);
-typedef glitz_gl_void_t (* glitz_gl_vertex_pointer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_vertex_pointer_t)
      (glitz_gl_int_t size, glitz_gl_enum_t type, glitz_gl_sizei_t stride,
       const glitz_gl_void_t *ptr);
-typedef glitz_gl_void_t (* glitz_gl_tex_coord_pointer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_coord_pointer_t)
      (glitz_gl_int_t size, glitz_gl_enum_t type, glitz_gl_sizei_t stride,
       const glitz_gl_void_t *ptr);
-typedef glitz_gl_void_t (* glitz_gl_draw_arrays_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_draw_arrays_t)
      (glitz_gl_enum_t mode, glitz_gl_int_t first, glitz_gl_sizei_t count);
-typedef glitz_gl_void_t (* glitz_gl_multi_draw_arrays_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_multi_draw_arrays_t)
      (glitz_gl_enum_t mode, glitz_gl_int_t *first, glitz_gl_sizei_t *count,
       glitz_gl_sizei_t primcount);
-typedef glitz_gl_void_t (* glitz_gl_tex_env_f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_env_f_t)
      (glitz_gl_enum_t target, glitz_gl_enum_t pname, glitz_gl_float_t param);
-typedef glitz_gl_void_t (* glitz_gl_tex_env_fv_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_env_fv_t)
      (glitz_gl_enum_t target, glitz_gl_enum_t pname,
       const glitz_gl_float_t *params);
-typedef glitz_gl_void_t (* glitz_gl_tex_gen_i_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_gen_i_t)
      (glitz_gl_enum_t coord, glitz_gl_enum_t pname, glitz_gl_int_t param);
-typedef glitz_gl_void_t (* glitz_gl_tex_gen_fv_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_gen_fv_t)
      (glitz_gl_enum_t coord, glitz_gl_enum_t pname,
       const glitz_gl_float_t *params);
-typedef glitz_gl_void_t (* glitz_gl_scissor_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_scissor_t)
      (glitz_gl_int_t x, glitz_gl_int_t y,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height);
-typedef glitz_gl_void_t (* glitz_gl_color_4us_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_color_4us_t)
      (glitz_gl_ushort_t red, glitz_gl_ushort_t green, glitz_gl_ushort_t blue,
       glitz_gl_ushort_t alpha);
-typedef glitz_gl_void_t (* glitz_gl_color_4f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_color_4f_t)
      (glitz_gl_float_t red, glitz_gl_float_t green, glitz_gl_float_t blue,
       glitz_gl_float_t alpha);
-typedef glitz_gl_void_t (* glitz_gl_blend_func_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_blend_func_t)
      (glitz_gl_enum_t sfactor, glitz_gl_enum_t dfactor);
-typedef glitz_gl_void_t (* glitz_gl_blend_color_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_blend_color_t)
      (glitz_gl_clampf_t red, glitz_gl_clampf_t green, glitz_gl_clampf_t blue,
       glitz_gl_clampf_t alpha);
-typedef glitz_gl_void_t (* glitz_gl_clear_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_clear_t)
      (glitz_gl_bitfield_t mask);
-typedef glitz_gl_void_t (* glitz_gl_clear_color_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_clear_color_t)
      (glitz_gl_clampf_t red, glitz_gl_clampf_t green,
       glitz_gl_clampf_t blue, glitz_gl_clampf_t alpha);
-typedef glitz_gl_void_t (* glitz_gl_clear_stencil_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_clear_stencil_t)
      (glitz_gl_int_t s);
-typedef glitz_gl_void_t (* glitz_gl_stencil_func_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_stencil_func_t)
      (glitz_gl_enum_t func, glitz_gl_int_t ref, glitz_gl_uint_t mask);
-typedef glitz_gl_void_t (* glitz_gl_stencil_op_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_stencil_op_t)
      (glitz_gl_enum_t fail, glitz_gl_enum_t zfail, glitz_gl_enum_t zpass);
-typedef glitz_gl_void_t (* glitz_gl_push_attrib_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_push_attrib_t)
      (glitz_gl_bitfield_t mask);
-typedef glitz_gl_void_t (* glitz_gl_pop_attrib_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_pop_attrib_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_matrix_mode_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_matrix_mode_t)
      (glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_push_matrix_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_push_matrix_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_pop_matrix_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_pop_matrix_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_load_identity_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_load_identity_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_load_matrix_f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_load_matrix_f_t)
      (const glitz_gl_float_t *m);
-typedef glitz_gl_void_t (* glitz_gl_depth_range_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_depth_range_t)
      (glitz_gl_clampd_t near_val, glitz_gl_clampd_t far_val);
-typedef glitz_gl_void_t (* glitz_gl_viewport_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_viewport_t)
      (glitz_gl_int_t x, glitz_gl_int_t y,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height);
-typedef glitz_gl_void_t (* glitz_gl_raster_pos_2f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_raster_pos_2f_t)
      (glitz_gl_float_t x, glitz_gl_float_t y);
-typedef glitz_gl_void_t (* glitz_gl_bitmap_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bitmap_t)
      (glitz_gl_sizei_t width, glitz_gl_sizei_t height,
       glitz_gl_float_t xorig, glitz_gl_float_t yorig,
       glitz_gl_float_t xmove, glitz_gl_float_t ymove,
       const glitz_gl_ubyte_t *bitmap);
-typedef glitz_gl_void_t (* glitz_gl_read_buffer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_read_buffer_t)
      (glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_draw_buffer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_draw_buffer_t)
      (glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_copy_pixels_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_copy_pixels_t)
      (glitz_gl_int_t x, glitz_gl_int_t y,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height,
       glitz_gl_enum_t type);
-typedef glitz_gl_void_t (* glitz_gl_flush_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_flush_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_finish_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_finish_t)
      (glitz_gl_void_t);
-typedef glitz_gl_void_t (* glitz_gl_pixel_store_i_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_pixel_store_i_t)
      (glitz_gl_enum_t pname, glitz_gl_int_t param);
-typedef glitz_gl_void_t (* glitz_gl_ortho_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_ortho_t)
      (glitz_gl_double_t left, glitz_gl_double_t right,
       glitz_gl_double_t bottom, glitz_gl_double_t top,
       glitz_gl_double_t near_val, glitz_gl_double_t far_val);
-typedef glitz_gl_void_t (* glitz_gl_scale_f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_scale_f_t)
      (glitz_gl_float_t x, glitz_gl_float_t y, glitz_gl_float_t z);
-typedef glitz_gl_void_t (* glitz_gl_translate_f_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_translate_f_t)
      (glitz_gl_float_t x, glitz_gl_float_t y, glitz_gl_float_t z);
-typedef glitz_gl_void_t (* glitz_gl_hint_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_hint_t)
      (glitz_gl_enum_t target, glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_depth_mask_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_depth_mask_t)
      (glitz_gl_boolean_t flag);
-typedef glitz_gl_void_t (* glitz_gl_polygon_mode_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_polygon_mode_t)
      (glitz_gl_enum_t face, glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_shade_model_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_shade_model_t)
      (glitz_gl_enum_t mode);
-typedef glitz_gl_void_t (* glitz_gl_color_mask_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_color_mask_t)
      (glitz_gl_boolean_t red,
       glitz_gl_boolean_t green,
       glitz_gl_boolean_t blue,
       glitz_gl_boolean_t alpha);
-typedef glitz_gl_void_t (* glitz_gl_read_pixels_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_read_pixels_t)
      (glitz_gl_int_t x, glitz_gl_int_t y,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height,
       glitz_gl_enum_t format, glitz_gl_enum_t type,
       glitz_gl_void_t *pixels);
-typedef glitz_gl_void_t (* glitz_gl_get_tex_image_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_tex_image_t)
      (glitz_gl_enum_t target, glitz_gl_int_t level,
       glitz_gl_enum_t format, glitz_gl_enum_t type,
       glitz_gl_void_t *pixels);
-typedef glitz_gl_void_t (* glitz_gl_tex_sub_image_2d_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_sub_image_2d_t)
      (glitz_gl_enum_t target, glitz_gl_int_t level,
       glitz_gl_int_t xoffset, glitz_gl_int_t yoffset,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height,
       glitz_gl_enum_t format, glitz_gl_enum_t type,
       const glitz_gl_void_t *pixels);
-typedef glitz_gl_void_t (* glitz_gl_gen_textures_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_gen_textures_t)
      (glitz_gl_sizei_t n, glitz_gl_uint_t *textures);
-typedef glitz_gl_void_t (* glitz_gl_delete_textures_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_delete_textures_t)
      (glitz_gl_sizei_t n, const glitz_gl_uint_t *textures);
-typedef glitz_gl_void_t (* glitz_gl_bind_texture_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bind_texture_t)
      (glitz_gl_enum_t target, glitz_gl_uint_t texture);
-typedef glitz_gl_void_t (* glitz_gl_tex_image_2d_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_image_2d_t)
      (glitz_gl_enum_t target, glitz_gl_int_t level,
       glitz_gl_int_t internal_format,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height,
       glitz_gl_int_t border, glitz_gl_enum_t format, glitz_gl_enum_t type,
       const glitz_gl_void_t *pixels);
-typedef glitz_gl_void_t (* glitz_gl_tex_parameter_i_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_parameter_i_t)
      (glitz_gl_enum_t target, glitz_gl_enum_t pname, glitz_gl_int_t param);
-typedef glitz_gl_void_t (* glitz_gl_get_tex_level_parameter_iv_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_tex_parameter_fv_t)
+     (glitz_gl_enum_t target, glitz_gl_enum_t pname,
+      const glitz_gl_float_t *parama);
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_tex_level_parameter_iv_t)
      (glitz_gl_enum_t target, glitz_gl_int_t level,
       glitz_gl_enum_t pname, glitz_gl_int_t *param);
-typedef glitz_gl_void_t (* glitz_gl_copy_tex_sub_image_2d_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_copy_tex_sub_image_2d_t)
      (glitz_gl_enum_t target, glitz_gl_int_t level,
       glitz_gl_int_t xoffset, glitz_gl_int_t yoffset,
       glitz_gl_int_t x, glitz_gl_int_t y,
       glitz_gl_sizei_t width, glitz_gl_sizei_t height);
-typedef glitz_gl_void_t (* glitz_gl_get_integer_v_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_integer_v_t)
      (glitz_gl_enum_t pname, glitz_gl_int_t *params);
-typedef glitz_gl_void_t (* glitz_gl_get_pointer_v_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_pointer_v_t)
      (glitz_gl_enum_t pname, glitz_gl_void_t **params);
-typedef glitz_gl_void_t (* glitz_gl_active_texture_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_active_texture_t)
      (glitz_gl_enum_t);
-typedef glitz_gl_void_t (* glitz_gl_client_active_texture_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_client_active_texture_t)
      (glitz_gl_enum_t);
-typedef glitz_gl_void_t (* glitz_gl_gen_programs_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_gen_programs_t)
      (glitz_gl_sizei_t, glitz_gl_uint_t *);
-typedef glitz_gl_void_t (* glitz_gl_delete_programs_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_delete_programs_t)
      (glitz_gl_sizei_t, const glitz_gl_uint_t *);
-typedef glitz_gl_void_t (* glitz_gl_program_string_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_program_string_t)
      (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_sizei_t,
       const glitz_gl_void_t *);
-typedef glitz_gl_void_t (* glitz_gl_bind_program_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bind_program_t)
      (glitz_gl_enum_t, glitz_gl_uint_t);
-typedef glitz_gl_void_t (* glitz_gl_program_local_param_4fv_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_program_local_param_4fv_t)
      (glitz_gl_enum_t, glitz_gl_uint_t, const glitz_gl_float_t *);
-typedef glitz_gl_void_t (* glitz_gl_get_program_iv_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_program_iv_t)
      (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_int_t *);
-typedef glitz_gl_void_t (* glitz_gl_gen_buffers_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_gen_buffers_t)
      (glitz_gl_sizei_t, glitz_gl_uint_t *buffers);
-typedef glitz_gl_void_t (* glitz_gl_delete_buffers_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_delete_buffers_t)
      (glitz_gl_sizei_t, const glitz_gl_uint_t *buffers);
-typedef glitz_gl_void_t (* glitz_gl_bind_buffer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bind_buffer_t)
      (glitz_gl_enum_t, glitz_gl_uint_t buffer);
-typedef glitz_gl_void_t (* glitz_gl_buffer_data_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_buffer_data_t)
      (glitz_gl_enum_t, glitz_gl_sizeiptr_t, const glitz_gl_void_t *,
       glitz_gl_enum_t);
-typedef glitz_gl_void_t *(* glitz_gl_buffer_sub_data_t)
+typedef glitz_gl_void_t *(GLITZ_GL_API_ATTRIBUTE * glitz_gl_buffer_sub_data_t)
      (glitz_gl_enum_t, glitz_gl_intptr_t, glitz_gl_sizeiptr_t,
       const glitz_gl_void_t *);
-typedef glitz_gl_void_t *(* glitz_gl_get_buffer_sub_data_t)
+typedef glitz_gl_void_t *(GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_buffer_sub_data_t)
      (glitz_gl_enum_t, glitz_gl_intptr_t, glitz_gl_sizeiptr_t,
       glitz_gl_void_t *);
-typedef glitz_gl_void_t *(* glitz_gl_map_buffer_t)
+typedef glitz_gl_void_t *(GLITZ_GL_API_ATTRIBUTE * glitz_gl_map_buffer_t)
      (glitz_gl_enum_t, glitz_gl_enum_t);
-typedef glitz_gl_boolean_t (* glitz_gl_unmap_buffer_t)
+typedef glitz_gl_boolean_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_unmap_buffer_t)
      (glitz_gl_enum_t);
-typedef void (* glitz_gl_gen_framebuffers_t)
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_gen_framebuffers_t)
      (glitz_gl_sizei_t, glitz_gl_uint_t *);
-typedef void (* glitz_gl_delete_framebuffers_t)
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_delete_framebuffers_t)
      (glitz_gl_sizei_t, const glitz_gl_uint_t *);
-typedef glitz_gl_void_t (* glitz_gl_bind_framebuffer_t)
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bind_framebuffer_t)
      (glitz_gl_enum_t, glitz_gl_uint_t);
-typedef glitz_gl_enum_t (* glitz_gl_check_framebuffer_status_t)
-     (glitz_gl_enum_t);
-typedef void (* glitz_gl_framebuffer_texture_2d_t)
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_framebuffer_renderbuffer_t)
+    (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_enum_t,
+     glitz_gl_uint_t);
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_framebuffer_texture_2d_t)
     (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_enum_t,
      glitz_gl_uint_t, glitz_gl_int_t);
+typedef glitz_gl_enum_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_check_framebuffer_status_t)
+     (glitz_gl_enum_t);
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_gen_renderbuffers_t)
+     (glitz_gl_sizei_t, glitz_gl_uint_t *);
+typedef void (GLITZ_GL_API_ATTRIBUTE * glitz_gl_delete_renderbuffers_t)
+     (glitz_gl_sizei_t, const glitz_gl_uint_t *);
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_bind_renderbuffer_t)
+     (glitz_gl_enum_t, glitz_gl_uint_t);
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_renderbuffer_storage_t)
+     (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_sizei_t, glitz_gl_sizei_t);
+typedef glitz_gl_void_t (GLITZ_GL_API_ATTRIBUTE * glitz_gl_get_renderbuffer_parameter_iv_t)
+     (glitz_gl_enum_t, glitz_gl_enum_t, glitz_gl_int_t *);
 
 #endif /* GLITZ_GL_H_INCLUDED */
